changeset 6615:687ae48b2253

[project @ 2007-05-13 06:24:57 by jwe]
author jwe
date Sun, 13 May 2007 06:24:58 +0000
parents 3a53d0f3e0e4
children 66e30383481b
files scripts/ChangeLog scripts/miscellaneous/doc.m scripts/miscellaneous/single.m scripts/miscellaneous/ver.m src/ChangeLog src/help.cc src/input.cc src/oct-hist.cc src/octave.cc src/toplev.cc
diffstat 10 files changed, 53 insertions(+), 46 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/ChangeLog	Sat May 12 05:50:04 2007 +0000
+++ b/scripts/ChangeLog	Sun May 13 06:24:58 2007 +0000
@@ -1,3 +1,13 @@
+2007-05-13  Søren Hauberg <soren@hauberg.org>
+
+	* miscellaneous/single.m: Doc fix.
+	Convert to double instead of returning argument unchanged.
+
+	* miscellaneous/doc.m: Doc fix.
+
+	* miscellaneous/ver.m: Doc fix.
+	Don't display information about Octave Forge.
+
 2007-05-12  David Bateman  <dbateman@free.fr>
 
 	* pkg/pkg.m: Add a "-verbose" option that allows all output of an
--- a/scripts/miscellaneous/doc.m	Sat May 12 05:50:04 2007 +0000
+++ b/scripts/miscellaneous/doc.m	Sun May 13 06:24:58 2007 +0000
@@ -17,12 +17,16 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Command} doc @var{function_name}
-## Displays documentation for the function @var{function_name}.
-## For example, if you want to see the documentation for the Octave
-## random number generator @code{rand}, type
-## @example
-## @code{doc rand}
-## @end example
+## Display documentation for the function @var{function_name}
+## directly from an on-line version of
+## the printed manual, using the GNU Info browser.  If invoked without
+## any arguments, the manual is shown from the beginning.
+##
+## For example, the command @kbd{doc rand} starts the GNU Info browser
+## at this node in the on-line version of the manual.
+##
+## Once the GNU Info browser is running, help for using it is available
+## using the command @kbd{C-h}.
 ## @seealso{help}
 ## @end deftypefn
 
--- a/scripts/miscellaneous/ver.m	Sat May 12 05:50:04 2007 +0000
+++ b/scripts/miscellaneous/ver.m	Sun May 13 06:24:58 2007 +0000
@@ -18,10 +18,9 @@
 ## 02110-1301, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} ver
-## @code{ver} displays a header containing the current Octave version
-## number, license string and operating system, followed by the version
-## number for octave-forge, if installed.
+## @deftypefn {Function File} {} ver ()
+## Display a header containing the current Octave version
+## number, license string and operating system.
 ## @seealso{license, version}
 ## @end deftypefn
 
@@ -52,17 +51,6 @@
   ver_desc = sprintf ("%s\n%s%s\n%s%s\n%s%s\n%s\n", hbar, ver_line1, version,
                       ver_line2, octave_license, ver_line3, os_string, hbar);
 
-  if (exist ("OCTAVE_FORGE_VERSION"))
-    octave_forge_name = "octave-forge";
-    octave_forge_version = num2str (OCTAVE_FORGE_VERSION);
-    octave_forge_string = sprintf ("%s%s%s\n", octave_forge_name,
-                                   blanks (round(0.75 * length (hbar))
-                                           - length (octave_forge_name)
-                                           - length (octave_forge_version)),
-                                   octave_forge_version);
-    ver_desc = strcat (ver_desc, octave_forge_string);
-  endif
-
   puts (ver_desc);
 
 endfunction
--- a/src/ChangeLog	Sat May 12 05:50:04 2007 +0000
+++ b/src/ChangeLog	Sun May 13 06:24:58 2007 +0000
@@ -1,3 +1,9 @@
+2007-05-13  Søren Hauberg  <soren@hauberg.org>
+
+	* toplev.cc (Fquit): Doc fix.
+	* help.cc (Fhelp): Doc fix.
+	* oct-hist.cc (Fsaving_history): Doc fix.
+
 2007-05-11  John W. Eaton  <jwe@octave.org>
 
 	* variables.cc (symbol_out_of_date):
@@ -73,7 +79,7 @@
 	* ov-usr-fcn.cc (octave_user_function::do_multi_index_op):
 	Only deal with varargout if ret_list->takes_varargs () is true.
 
-2007-04-26  Soren Hauberg  <soren@hauberg.org>
+2007-04-26  Søren Hauberg  <soren@hauberg.org>
 
 	* DLD-FUNCTIONS/urlwrite.cc: Doc fix.
 
@@ -102,7 +108,7 @@
         (color_property::validate): Use rgba.
         (color_property::c2rgba): New function.
 
-2007-04-23  Soren Hauberg  <soren@hauberg.org>
+2007-04-23  Søren Hauberg  <soren@hauberg.org>
 
 	* data.cc (Fsize_equal): Allow more than two arguments.
 
@@ -1502,7 +1508,7 @@
 	New functions.
 	* ov-base-int.h: Provide decls.
 
-2006-09-15  Soren Hauberg  <soren@hauberg.org>.
+2006-09-15  Søren Hauberg  <soren@hauberg.org>.
 
 	* data.cc (Fsize): If nargout > ndims, fill with 1.
 
@@ -3608,7 +3614,7 @@
 	* help.cc (help_from_info): Simplify.
 	(try_info): Use feval to call doc instead of executing info program.
 	(additional_help_message): Point users to doc instead of help -i.
-	From Soren Hauberg <soren@hauberg.org>.
+	From Søren Hauberg <soren@hauberg.org>.
 
 	* toplev.cc (Fsystem): Return output if nargout > 1, not 0.
 
@@ -4455,7 +4461,7 @@
 
 2005-07-18  John W. Eaton  <jwe@octave.org>
 
-	* strfns.cc (Fstrcmp): New function from Soren Hauberg
+	* strfns.cc (Fstrcmp): New function from Søren Hauberg
 	<soren@hauberg.org> and Tom Holroyd <tomh@kurage.nimh.nih.gov>.
 	Adapt to Octave conventions.
 
--- a/src/help.cc	Sat May 12 05:50:04 2007 +0000
+++ b/src/help.cc	Sun May 13 06:24:58 2007 +0000
@@ -1156,21 +1156,17 @@
 
 DEFCMD (help, args, ,
   "-*- texinfo -*-\n\
-@deffn {Command} help\n\
-Octave's @code{help} command can be used to print brief usage-style\n\
-messages, or to display information directly from an on-line version of\n\
-the printed manual, using the GNU Info browser.  If invoked without any\n\
-arguments, @code{help} prints a list of all the available operators\n\
-and functions.  If the first argument is @code{-i}, the @code{help}\n\
-command searches the index of the on-line version of this manual for\n\
-the given topics.\n\
+@deffn {Command} help @var{name}\n\
+Display the help text for @var{name}.\n\
+If invoked without any arguments, @code{help} prints a list\n\
+of all the available operators and functions.\n\
 \n\
 For example, the command @kbd{help help} prints a short message\n\
-describing the @code{help} command, and @kbd{help -i help} starts the\n\
-GNU Info browser at this node in the on-line version of the manual.\n\
+describing the @code{help} command.\n\
 \n\
-Once the GNU Info browser is running, help for using it is available\n\
-using the command @kbd{C-h}.\n\
+The help command can give you information about operators, but not the\n\
+comma and semicolons that are used as command separators.  To get help\n\
+for those, you must type @kbd{help comma} or @kbd{help semicolon}.\n\
 @seealso{doc, which, lookfor}\n\
 @end deffn")
 {
--- a/src/input.cc	Sat May 12 05:50:04 2007 +0000
+++ b/src/input.cc	Sun May 13 06:24:58 2007 +0000
@@ -1058,7 +1058,10 @@
 @deftypefn {Built-in Function} {} read_readline_init_file (@var{file})\n\
 Read the readline library initialiazation file @var{file}.  If\n\
 @var{file} is omitted, read the default initialization file (normally\n\
-@file{~/.inputrc}.\n\
+@file{~/.inputrc}).\n\
+\n\
+@xref{Readline Init File, , , readline, GNU Readline Library},\n\
+for details.\n\
 @end deftypefn")
 {
   octave_value_list retval;
--- a/src/oct-hist.cc	Sat May 12 05:50:04 2007 +0000
+++ b/src/oct-hist.cc	Sun May 13 06:24:58 2007 +0000
@@ -739,7 +739,7 @@
 @deftypefnx {Built-in Function} {@var{old_val} =} saving_history (@var{new_val})\n\
 Query or set the internal variable that controls whether commands entered\n\
 on the command line are saved in the history file.\n\
-@seealso{history_file, history_size, history_timestamp_format}.\n\
+@seealso{history_file, history_size, history_timestamp_format}\n\
 @end deftypefn")
 {
   octave_value retval = SET_INTERNAL_VARIABLE (saving_history);
--- a/src/octave.cc	Sat May 12 05:50:04 2007 +0000
+++ b/src/octave.cc	Sun May 13 06:24:58 2007 +0000
@@ -443,7 +443,7 @@
   --eval CODE             Evaluate CODE.  Exit when done unless --persist.\n\
   --exec-path PATH        Set path for executing subprograms.\n\
   --help, -h, -?          Print short help message and exit.\n\
-  --image-path PATH       Set initial IMAGEPATH to PATH.\n\
+  --image-path PATH       Set initial IMAGE_PATH to PATH.\n\
   --info-file FILE        Use top-level info file FILE.\n\
   --info-program PROGRAM  Use PROGRAM for reading info files.\n\
   --interactive, -i       Force interactive behavior.\n\
--- a/src/toplev.cc	Sat May 12 05:50:04 2007 +0000
+++ b/src/toplev.cc	Sun May 13 06:24:58 2007 +0000
@@ -301,7 +301,7 @@
 @deftypefnx {Built-in Function} {} quit (@var{status})\n\
 Exit the current Octave session.  If the optional integer value\n\
 @var{status} is supplied, pass that value to the operating system as the\n\
-Octave's exit status.\n\
+Octave's exit status.  The default value is zero.\n\
 @end deftypefn")
 {
   octave_value_list retval;
--- a/scripts/miscellaneous/single.m	Sat May 12 05:50:04 2007 +0000
+++ b/scripts/miscellaneous/single.m	Sun May 13 06:24:58 2007 +0000
@@ -21,15 +21,15 @@
 ## @deftypefn {Function File} {} single (@var{val})
 ## Convert the numeric value @var{val} to single precision.
 ##
 ## @strong{Note}: this function currently returns its argument unchanged
 ## because Octave does not yet have a single-precision numeric data
 ## type.
 ## @end deftypefn
 
 function retval = single (val)
 
   if (nargin == 1 && isnumeric (val))
-    retval = val;
+    retval = double(val);
   else
     print_usage ();
   endif
@@ -21,15 +21,15 @@
 ## Convert the numeric value @var{val} to single precision.
 ##
-## @strong{Note}: this function currently returns its argument unchanged
-## because Octave does not yet have a single-precision numeric data
-## type.
+## @strong{Note}: this function currently returns its argument converted
+## to double precision because Octave does not yet have a single-precision
+## numeric data type.
 ## @end deftypefn
 